@@ -17,7 +17,6 @@ import (
 
 	mcfgv1 "github.com/openshift/machine-config-operator/pkg/apis/machineconfiguration.openshift.io/v1"
 	ctrlcommon "github.com/openshift/machine-config-operator/pkg/controller/common"
-	"github.com/openshift/machine-config-operator/pkg/version"
 )
 
 // syncVersion handles reporting the version to the clusteroperator
@@ -66,9 +65,13 @@ func (optr *Operator) syncRelatedObjects() error {
 	// RelatedObjects are consumed by https://github.com/openshift/must-gather
 	co.Status.RelatedObjects = []configv1.ObjectReference{
 		{Resource: "namespaces", Name: optr.namespace},
-		{Group: "machineconfiguration.openshift.io", Resource: "machineconfigpools", Name: "master"},
-		{Group: "machineconfiguration.openshift.io", Resource: "machineconfigpools", Name: "worker"},
-		{Group: "machineconfiguration.openshift.io", Resource: "controllerconfigs", Name: "machine-config-controller"},
+		{Group: "machineconfiguration.openshift.io", Resource: "machineconfigpools"},
+		{Group: "machineconfiguration.openshift.io", Resource: "controllerconfigs"},
+		{Group: "machineconfiguration.openshift.io", Resource: "kubeletconfigs"},
+		{Group: "machineconfiguration.openshift.io", Resource: "containerruntimeconfigs"},
+		{Group: "machineconfiguration.openshift.io", Resource: "machineconfigs"},
+		// gathered because the machineconfigs created container bootstrap credentials and node configuration that gets reflected via the API and is needed for debugging
+		{Group: "", Resource: "nodes"},
 	}
 
 	if !equality.Semantic.DeepEqual(coCopy.Status.RelatedObjects, co.Status.RelatedObjects) {
@@ -244,6 +247,12 @@ func (optr *Operator) syncUpgradeableStatus() error {
 	if co == nil {
 		return nil
 	}
+
+	pools, err := optr.mcpLister.List(labels.Everything())
+	if err != nil {
+		return err
+	}
+
 	// Report default "Upgradeable=True" status. When known hazardous states for upgrades are
 	// determined, specific "Upgradeable=False" status can be added with messages for how admins
 	// can resolve it.
@@ -253,6 +262,15 @@ func (optr *Operator) syncUpgradeableStatus() error {
 		Status: configv1.ConditionTrue,
 		Reason: asExpectedReason,
 	}
+	for _, pool := range pools {
+		degraded := isPoolStatusConditionTrue(pool, mcfgv1.MachineConfigPoolDegraded)
+		if degraded {
+			coStatus.Status = configv1.ConditionFalse
+			coStatus.Reason = "DegradedPool"
+			coStatus.Message = "One or more machine config pool is degraded, please see `oc get mcp` for further details and resolve before upgrading"
+		}
+	}
+
 	return optr.updateStatus(co, coStatus)
 }
 
@@ -330,13 +348,7 @@ func (optr *Operator) allMachineConfigPoolStatus() (map[string]string, error) {
 	}
 	ret := map[string]string{}
 	for _, pool := range pools {
-		p := pool.DeepCopy()
-		err := isMachineConfigPoolConfigurationValid(p, version.Hash, optr.mcLister.Get)
-		if err != nil {
-			glog.V(4).Infof("Skipping status for pool %s because %v", p.GetName(), err)
-			continue
-		}
-		ret[p.GetName()] = machineConfigPoolStatus(p)
+		ret[pool.GetName()] = machineConfigPoolStatus(pool)
 	}
 	return ret, nil
 }
@@ -345,7 +357,7 @@ func (optr *Operator) allMachineConfigPoolStatus() (map[string]string, error) {
 func isMachineConfigPoolConfigurationValid(pool *mcfgv1.MachineConfigPool, version string, machineConfigGetter func(string) (*mcfgv1.MachineConfig, error)) error {
 	// both .status.configuration.name and .status.configuration.source must be set.
 	if pool.Spec.Configuration.Name == "" {
-		return fmt.Errorf("configuration spec for pool %s is empty", pool.GetName())
+		return fmt.Errorf("configuration spec for pool %s is empty: %v", pool.GetName(), machineConfigPoolStatus(pool))
 	}
 	if pool.Status.Configuration.Name == "" {
 		// if status is empty, it means the node controller hasn't seen any node at the target configuration
@@ -353,7 +365,7 @@ func isMachineConfigPoolConfigurationValid(pool *mcfgv1.MachineConfigPool, versi
 		return fmt.Errorf("configuration status for pool %s is empty: %s", pool.GetName(), machineConfigPoolStatus(pool))
 	}
 	if len(pool.Status.Configuration.Source) == 0 {
-		return fmt.Errorf("list of MachineConfigs that were used to generate configuration for pool %s is empty", pool.GetName())
+		return fmt.Errorf("list of MachineConfigs that were used to generate configuration for pool %s is empty: %v", pool.GetName(), machineConfigPoolStatus(pool))
 	}
 	mcs := []string{pool.Status.Configuration.Name}
 	for _, fragment := range pool.Status.Configuration.Source {
@@ -372,13 +384,13 @@ func isMachineConfigPoolConfigurationValid(pool *mcfgv1.MachineConfigPool, versi
 		// The bootstrapped MCs fragments have this annotation, however, we don't fail (???) if they don't have
 		// the annotation for some reason.
 		if !ok && pool.Status.Configuration.Name == mcName {
-			return fmt.Errorf("%s must be created by controller version %s", mcName, version)
+			return fmt.Errorf("%s must be created by controller version %s: %v", mcName, version, machineConfigPoolStatus(pool))
 		}
 		// user provided MC fragments do not have the annotation, so we just skip the version check there.
 		// The check below is for: 1) the generated MC for the pool, and 2) the bootstrapped fragments
 		// that do have this annotation set with a version.
 		if ok && v != version {
-			return fmt.Errorf("controller version mismatch for %s expected %s has %s", mcName, version, v)
+			return fmt.Errorf("controller version mismatch for %s expected %s has %s: %v", mcName, version, v, machineConfigPoolStatus(pool))
 		}
 	}
 	return nil
